@@ -54,7 +54,7 @@ MojoX::Session::Transport::Cookie - Cookie Transport for MojoX::Session
 =head1 SYNOPSIS
 
     my $session = MojoX::Session->new(
-        transport => MojoX::Session::Transport::Cookie->new(tx => $tx),
+        transport => MojoX::Session::Transport::Cookie->new,
         ...
     );
 
@@ -67,13 +67,6 @@ gets and sets session id to and from cookies.
 
 L<MojoX::Session::Transport::Cookie> implements the following attributes.
 
-=head2 C<tx>
-
-    my $tx = $transport->tx;
-    $transport = $transport->tx($tx);
-
-Get and set L<Mojo::Transaction> object.
-
 =head2 C<path>
 
     my $path = $transport->path;
@@ -114,7 +107,7 @@ vti, C<vti@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2008, Viacheslav Tikhanovskii.
+Copyright (C) 2008, Viacheslav Tykhanovskyi.
 
 This program is free software, you can redistribute it and/or modify it under
 the same terms as Perl 5.10.
